==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/64/html-menu-treeview/preload.js <==
folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(64,64);
plusNodeClosed.src='/style/Crystal/64/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(64,64);
lastPlusNodeClosed.src='/style/Crystal/64/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(64,64);
clasicPlusNodeClosed.src='/style/Crystal/64/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(64,64);
clasicLastPlusNodeClosed.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.5.tar.gz: HTML-Menu-TreeView-0.6.5/htdocs/style/Crystal/64/html-menu-treeview/preload.js <==
folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folderClosed.gif';
plusNode = new Image(64,64);
plusNode.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(64,64);
lastplusNode.src='/style/Crystal/64/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(64,64);
clasicplusNode.src='/style/Crystal/64/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(64,64);
clasicLastplusNode.src='/style/Crystal/64/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folderTarClosed.gif';
